@@ -1,7 +1,7 @@
 package Simo::Error;
 use 5.008_001;
 
-our $VERSION = '0.0207';
+our $VERSION = '0.0301';
 
 use warnings;
 use strict;
@@ -145,11 +145,17 @@ sub throw{
 
 =head1 NAME
 
-Simo::Error - Error object for Simo
+Simo::Error - Error object for Simo [DISCOURAGED]
+
+=head1 CAUTION
+
+This module is discouraged now, because I develope new module L<Object::Simple> now.
+
+L<Object::Simple> is very simple class builder. It is clean, compact, and fast.
 
 =head1 VERSION
 
-Version 0.0207
+Version 0.0301
 
 =cut
 
